@@ -1,6 +1,6 @@
 """This package exports the main entry point function for Botstrap's standalone CLI."""
 
-from botstrap.cli.main import main
+from botstrap.cli.menu import main
 
 __all__ = [
     "main",
